%define pkgname font-utils

# NOTE: When enabled, this provides symbolic links in /usr/X11R6/bin which
# provide backward compatibility for utilities/scripts that hard code paths
# to /usr/X11R6/bin/mkfontdir et al.  This compatibility support will be
# disabled and removed in a future OS release, so 3rd party application
# developers and package maintainers should update their software as soon
# as possible.
%define with_X11R6_compat 1
%define _x11r6bindir /usr/X11R6/bin

Summary: 	X.Org X11 font utilities
Name: 		xorg-x11-%{pkgname}
# IMPORTANT: If package ever gets renamed to something else, remove the Epoch line!
Epoch: 		1
# NOTE: Keep version set to the X11Rx.y release the package is based upon.
Version: 	7.3
# Bump release for updates.
Release: 	1
License: 	MIT/X11
Group: 		User Interface/X
URL: 		http://www.x.org
BuildRoot: 	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

Source0: 	http://xorg.freedesktop.org/releases/individual/app/bdftopcf-1.0.1.tar.bz2
Source1: 	http://xorg.freedesktop.org/releases/individual/app/fonttosfnt-1.0.3.tar.bz2
Source2: 	http://xorg.freedesktop.org/releases/individual/app/mkfontdir-1.0.3.tar.bz2
Source3: 	http://xorg.freedesktop.org/releases/individual/app/mkfontscale-1.0.3.tar.bz2
Source4: 	http://xorg.freedesktop.org/releases/individual/app/font-util-1.0.1.tar.bz2

Patch0: 	font-util-1.0.1-mapdir-use-datadir-fix.patch
Patch1: 	font-util-1.0.1-autoconf-add-with-fontdir-option.patch

BuildRequires: 	pkg-config
# xorg-x11-libXfont-devel needed for bdftopcf
BuildRequires: 	libXfont-devel
# xorg-x11-libX11-devel needed for fonttosfnt
BuildRequires: 	libX11-devel
# xorg-x11-libfontenc-devel needed for fonttosfnt, mkfontscale
BuildRequires: 	libfontenc-devel
# freetype-devel needed for bdftopcf, fonttosfnt, mkfontscale
BuildRequires: 	freetype-devel
# zlib-devel needed for bdftopcf
BuildRequires: 	zlib-devel
# xorg-x11-proto-devel is needed for mkfontscale, which includes headers
# from it directly.
BuildRequires: 	xorg-x11-proto-devel

BuildRequires: 	autoconf

Requires(pre): 	xorg-x11-filesystem >= 0.99.2-3

# NOTE: This versioned pre-dependency is needed to ensure that the bugfix for
# bug #173875 is installed in order for mkfontscale/mkfontdir to work
# properly.  It is a "pre" dep, to ensure libfontenc gets installed before
# xorg-font-utils, before any fonts in an rpm upgrade or multi-transaction
# set, avoiding a possible race condition.
Requires(pre): 	libfontenc >= 0.99.2-2

Provides: 	%{pkgname}
Provides: 	bdftopcf, fonttosfnt, mkfontdir, mkfontscale, bdftruncate, ucs2any
# NOTE: The fonts/util subdir moved from xorg-x11-base-fonts to
# xorg-x11-font-utils in 6.7.99.903-3
Obsoletes: 	xorg-base-fonts
# NOTE: ucs2any moved from xorg-x11-tools to xorg-x11-font-utils in 6.7.99.903-3
Obsoletes: 	xorg-tools
Obsoletes:	xorg-font-utils

%description
X.Org X11 font utilities required for font installation, conversion,
and generation.

%prep
%setup -q -c %{name}-%{version} -a1 -a2 -a3 -a4
%patch0 -p0 -b .font-util-mapdir-use-datadir-fix
%patch1 -p0 -b .autoconf-add-with-fontdir-option

%build
# Build all apps
{
   for app in bdftopcf fonttosfnt mkfontdir mkfontscale font-util ; do
      pushd $app-*
      # FIXME: We run autoconf to activate font-util-0.99.1-mapdir-use-datadir-fix.patch
      case $app in
         font-util)
            autoconf
            ;;
      esac
      %configure
      make
      popd
   done
}

%install
rm -rf $RPM_BUILD_ROOT
# Install all apps
{
   for app in bdftopcf fonttosfnt mkfontdir mkfontscale font-util; do
      pushd $app-*
      make install DESTDIR=$RPM_BUILD_ROOT
      popd
   done
}

%if %{with_X11R6_compat}
{
   mkdir -p $RPM_BUILD_ROOT%{_x11r6bindir}

   for util in mkfontdir mkfontscale ; do
      ln -sf ../../..%{_bindir}/$util $RPM_BUILD_ROOT%{_x11r6bindir}/$util
   done
}
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
# FIXME: Include missing docs sometime
%doc
%{_bindir}/bdftopcf
%{_bindir}/bdftruncate
%{_bindir}/fonttosfnt
%{_bindir}/mkfontdir
%{_bindir}/mkfontscale
%{_bindir}/ucs2any
# NOTE: These compat symlinks will be removed in a future OS release.
# Developers and package maintainers should update their software to handle
# the X11R7 changes in a clean manner.
%if %{with_X11R6_compat}
%dir %{_x11r6bindir}
%{_x11r6bindir}/mkfontdir
%{_x11r6bindir}/mkfontscale
%endif
%dir %{_datadir}/X11
%dir %{_datadir}/X11/fonts
%dir %{_datadir}/X11/fonts/util
%{_datadir}/X11/fonts/util/map-*
%{_datadir}/aclocal/fontutil.m4
%{_libdir}/pkgconfig/fontutil.pc
%{_mandir}/man1

%changelog
* Sat Sep 09 2007 Karsten Brockmann <arcam@ccux-linux.de> 1:7.3-1
- Version update
- bdftopcf 1.0.1
- fonttosfnt 1.0.3
- mkfontdir 1.0.3
- mkfontscale 1.0.3
* Mon Sep 10 2006 Christian Metzen <metzench@ccux-linux.de> 1:7.1-2
- adjusted obsoletes
* Sun Jul 02 2006 Christian Metzen <metzench@ccux-linux.de> 1:7.1-1
- Initial release
